<?xml version="1.0" encoding="UTF-8"?>
<!--

    XSLT for converting Flickr API responses into XML-Data (the XML-RPC encoding format).

    Phillip Pearson, 25 May 2005

    http://www.myelin.co.nz/post/2006/5/25/#200605251

-->

<xsl:transform 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <xsl:output indent="yes" omit-xml-declaration="yes" method="xml"/>

  <!-- eat any stray text -->
  <xsl:template match="text()" />

  <!-- root -->
  <xsl:template match="/">
    <methodResponse>
      <xsl:apply-templates/>
    </methodResponse>
  </xsl:template>

  <!-- handle errors -->
  <xsl:template match="rsp[@stat='fail']">
    <fault>
      <value>
	<struct>
	  <member>
	    <name>faultCode</name>
	    <value><int><xsl:value-of select="err/@code"/></int></value>
	  </member>
	  <member>
	    <name>faultString</name>
	    <value><string><xsl:value-of select="err/@msg"/></string></value>
	  </member>
	</struct>
      </value>
    </fault>
  </xsl:template>
  
  <!-- handle successful responses -->
  <xsl:template match="rsp[@stat='ok']">
    <params>
      <param>
	<value>
	  <struct>
	    <xsl:apply-templates/>
	  </struct>
	</value>
      </param>
    </params>
  </xsl:template>

  <!-- contact list response -->
  <xsl:template match="contacts">
    <member>
      <name>contacts</name>
      <value><array><data>
	<xsl:apply-templates/>
      </data></array></value>
    </member>
  </xsl:template>

  <xsl:template match="contact">
    <struct>
      <member><name>nsid</name><value><xsl:value-of select="@nsid"/></value></member>
      <member><name>username</name><value><xsl:value-of select="@username"/></value></member>
      <member><name>iconserver</name><value><i4><xsl:value-of select="@iconserver"/></i4></value></member>
      <member><name>ignored</name><value><boolean><xsl:value-of select="@ignored"/></boolean></value></member>
    </struct>
  </xsl:template>

  <!-- single user response -->
  <xsl:template match="user">
    <member>
      <name>user</name>
      <value>
	<struct>
	  <member><name>id</name><value><xsl:value-of select="@id"/></value></member>
	  <member><name>nsid</name><value><xsl:value-of select="@nsid"/></value></member>
	  <member><name>username</name><value><xsl:value-of select="username/text()"/></value></member>
	</struct>
      </value>
    </member>
  </xsl:template>

  <!-- person response -->
 <xsl:template match="person">
   <member>
      <name>person</name>
      <value>
	<struct>
	  <member><name>id</name><value><xsl:value-of select="@id"/></value></member>
	  <member><name>nsid</name><value><xsl:value-of select="@nsid"/></value></member>
	  <member><name>isadmin</name><value><boolean><xsl:value-of select="@isadmin"/></boolean></value></member>
	  <member><name>ispro</name><value><boolean><xsl:value-of select="@ispro"/></boolean></value></member>
	  <member><name>iconserver</name><value><xsl:value-of select="@iconserver"/></value></member>
	  <member><name>username</name><value><xsl:value-of select="username/text()"/></value></member>
	  <member><name>realname</name><value><xsl:value-of select="realname/text()"/></value></member>
	  <member><name>mbox_sha1sum</name><value><xsl:value-of select="mbox_sha1sum/text()"/></value></member>
	  <member><name>location</name><value><xsl:value-of select="location/text()"/></value></member>
	  <member><name>photosurl</name><value><xsl:value-of select="photosurl/text()"/></value></member>
	  <member><name>profileurl</name><value><xsl:value-of select="profileurl/text()"/></value></member>
	  <member>
	    <name>photos</name>
	    <value><struct>
	      <member><name>firstdatetaken</name><value><xsl:value-of select="photos/firstdatetaken/text()"/></value></member>
	      <member><name>firstdate</name><value><i4><xsl:value-of select="photos/firstdate/text()"/></i4></value></member>
	      <member><name>count</name><value><i4><xsl:value-of select="photos/count/text()"/></i4></value></member>
	    </struct></value>
	  </member>
	</struct>
      </value>
    </member>
 </xsl:template>

</xsl:transform>
